@@ -101,8 +101,8 @@ class DeviceManager(metaclass=MetaSingleton):
         logger.error('replication stopped')
         tl_track = self._core.playback.get_current_tl_track().get()
         state = self._core.playback.get_state().get()
-        logger.error("current playback state")
-        logger.error(state)
+        logger.debug("current playback state")
+        logger.debug(state)
         if state == PlaybackState.PLAYING:
           self._core.playback.play(tl_track)
 
